@@ -63,11 +63,11 @@ def parse_options(argv):
                 usage()
                 sys.exit()
             if opt in ("-s", "--src"):
-                cfg['src_path'] = arg.lstrip()
+                cfg['src_path'] = arg.strip(" \"\'")
             if opt in ("-r", "--ref"):
-                cfg['ref_path'] = arg.lstrip()
+                cfg['ref_path'] = arg.strip(" \"\'")
             if opt in ("-m", "--method"):
-                cfg['method'] = arg.lstrip()
+                cfg['method'] = arg.strip(" \"\'")
             if opt in ("-w", "--win"):
                 cfg['win'] = True
 
